@@ -1,32 +1,34 @@
 import datetime as dt
-import logging
 from abc import ABC, abstractmethod
-from typing import TYPE_CHECKING, Iterator, Optional, Type
+from typing import TYPE_CHECKING, Iterator, Optional, Type, Union
 
 import jinja2
 from pydantic import BaseModel
 
+from flowmaster.utils.logging_helper import Logger, getLogger
+
 if TYPE_CHECKING:
     from flowmaster.operators.base.policy import PydanticModelT
-    from flowmaster.operators.etl.policy import ETLFlowConfig
+    from flowmaster.operators.etl.policy import ETLNotebook
     from flowmaster.operators.etl.transform import Transform
     from flowmaster.operators.etl.dataschema import ExportContext
+    from flowmaster.executors import SleepIteration
 
 
 class ExportAbstract(ABC):
-    def __init__(
-        self, config: "ETLFlowConfig", logger: Optional[logging.Logger] = None
-    ):
-        self.config = config
-        self.logger = logger or logging.getLogger(__name__)
+    def __init__(self, notebook: "ETLNotebook", logger: Optional[Logger] = None):
+        self.notebook = notebook
+        self.logger = logger or getLogger()
 
     @classmethod
     def validate_params(cls, **params: dict) -> None:
+        # TODO: drop method
         ...
 
     def collect_params(
         self, start_period: dt.datetime, end_period: dt.datetime, **params
     ) -> dict:
+        # TODO: drop method
         new_params = {}
         for key, value in params.items():
             if value is not None:
@@ -51,6 +53,7 @@ class ExportAbstract(ABC):
     def model_templating(
         self, start_period: dt.datetime, end_period: dt.datetime, model: BaseModel
     ):
+        # TODO: replace method with function
         new_model_dict = {}
         for key, value in model.dict(exclude_unset=True).items():
             new_model_dict[key] = value
@@ -61,9 +64,9 @@ class ExportAbstract(ABC):
                         "start_period": start_period,
                         "end_period": end_period,
                         "datetime": dt.datetime.now(),
-                        "name": self.config.name,
-                        "provider": self.config.provider,
-                        "storage": self.config.storage,
+                        "name": self.notebook.name,
+                        "provider": self.notebook.provider,
+                        "storage": self.notebook.storage,
                     }
                 )
 
@@ -72,7 +75,9 @@ class ExportAbstract(ABC):
         return model.parse_obj(new_model_dict)
 
     @abstractmethod
-    def __call__(self, *args, **kwargs) -> Iterator["ExportContext"]:
+    def __call__(
+        self, *args, **kwargs
+    ) -> Iterator[Union["ExportContext", "SleepIteration"]]:
         ...
 
 
