@@ -3,7 +3,7 @@ from typing import Iterator
 
 from mock import Mock
 
-from flowmaster.operators.etl.policy import ETLFlowConfig
+from flowmaster.operators.etl.policy import ETLNotebook
 from flowmaster.operators.etl.providers.yandex_metrika_logs.export import (
     YandexMetrikaLogsExport,
 )
@@ -11,7 +11,7 @@ from flowmaster.operators.etl.service import ETLOperator
 from flowmaster.utils.yaml_helper import YamlHelper
 from tests import get_tests_dir
 from tests.fixtures.yandex_metrika import (
-    yml_visits_to_csv_config,
+    yml_visits_to_csv_notebook,
 )
 
 credentials = YamlHelper.parse_file(get_tests_dir("tests2") / "credentials.yml")
@@ -21,16 +21,16 @@ def test_codex_telegram():
     def export_func(start_period, end_period) -> Iterator[tuple[dict, list, list]]:
         yield ({}, ["date"], [[start_period]])
 
-    yml_visits_to_csv_config.work.notifications = ETLFlowConfig.WorkPolicy.NotificationsPolicy(
-        codex_telegram=ETLFlowConfig.WorkPolicy.NotificationsPolicy.CodexTelegramPolicy(
+    yml_visits_to_csv_notebook.work.notifications = ETLNotebook.WorkPolicy.NotificationsPolicy(
+        codex_telegram=ETLNotebook.WorkPolicy.NotificationsPolicy.CodexTelegramPolicy(
             links=[credentials["codex_telegram"]],
             on_success=True,
         )
     )
-    config = ETLFlowConfig(**dict(yml_visits_to_csv_config))
+    notebook = ETLNotebook(**dict(yml_visits_to_csv_notebook))
 
     YandexMetrikaLogsExport.__call__ = Mock(side_effect=export_func)
-    etl_flow = ETLOperator(config)
+    etl_flow = ETLOperator(notebook)
 
     list(
         etl_flow(
